==> react-native-onboard-2.4.25.tgz: package/lib/OnboardFlow/index.js <==
import React, { useEffect, useRef, useState } from 'react';
import { Dimensions, ImageBackground, Modal, SafeAreaView, StyleSheet, Text, TouchableOpacity, View, } from 'react-native';
import { Page } from './Page';
import { SwiperFlatList } from './Swiper';
import { COLOR_PAGINATION_DEFAULT, COLOR_PAGINATION_SELECTED_DEFAULT, DEFAULT_PAGE_TYPES, HORIZONTAL_PADDING_DEFAULT, VERTICAL_PADDING_DEFAULT, } from './constants';
import { PrimaryButton } from './components/PrimaryButton';
import { Footer } from './Footer';
import { SecondaryButton } from './components/SecondaryButton';
import { DotPagination } from './Pagination/components/Dot';
import { BottomSheet } from './BottomSheet';
export const OnboardFlow = ({ autoPlay = false, backgroundImageUri, dismissButtonStyle, fullscreenModal, textStyle, onBack, onDone, onNext, onSaveData, pageStyle, pageTypes = DEFAULT_PAGE_TYPES, pages, paginationColor = COLOR_PAGINATION_DEFAULT, paginationSelectedColor = COLOR_PAGINATION_SELECTED_DEFAULT, showDismissButton = false, enableScroll = true, style, subtitleStyle, textAlign = 'center', titleStyle, type = 'fullscreen', HeaderComponent = () => null, customVariables = {}, FooterComponent = Footer, PaginationComponent = DotPagination, PrimaryButtonComponent = PrimaryButton, SecondaryButtonComponent = SecondaryButton, ...props }) => {
    const pagesMerged = { ...DEFAULT_PAGE_TYPES, ...pageTypes };
    const [currentPage, setCurrentPage] = useState(0);
    const [modalVisible, setModalVisible] = useState(true);
    const swiperRef = useRef();
    const [containerWidth, setContainerWidth] = useState(Dimensions.get('window').width ?? 0);
    const windowHeight = Dimensions.get('window').height;
    const [maxTextHeight, setMaxTextHeight] = useState(0);
    const bottomSheetRef = useRef(null);
    const showHeader = pages[currentPage].showHeader == undefined || pages[currentPage].showHeader === true;
    const showFooter = pages[currentPage].showFooter == undefined || pages[currentPage].showFooter === true;
    const components = {
        PrimaryButtonComponent,
        PaginationComponent,
        SecondaryButtonComponent,
    };
    const onLayout = (event) => {
        setContainerWidth(event.nativeEvent.layout.width);
    };
    useEffect(() => {
        if (onSaveData && pages[currentPage]) {
            onSaveData({
                data: {
                    type: 'IMPRESSION',
                    page: pages[currentPage].type ?? 'default',
                },
                source: pages[currentPage],
            }, getPageId(pages[currentPage], currentPage));
        }
    }, [currentPage]);
    function getPageId(pageData, index) {
        return pageData?.id ?? index + '';
    }
    function handleIndexChange(item) {
        if (item.index != currentPage) {
            setCurrentPage(item.index);
        }
        if (item.index > item.prevIndex) {
            onNext && onNext();
            return;
        }
        if (item.index < item.prevIndex) {
            onBack && onBack();
            return;
        }
    }
    function handleDone() {
        setModalVisible(false);
        bottomSheetRef.current?.close();
        onDone && onDone();
    }
    function goToNextPage() {
        if (currentPage >= pages?.length - 1) {
            handleDone();
            return;
        }
        const nextIndex = swiperRef.current?.getCurrentIndex() + 1;
        setCurrentPage(nextIndex);
        swiperRef.current?.scrollToIndex({ index: nextIndex });
    }
    function goToPreviousPage() {
        const nextIndex = swiperRef.current?.getCurrentIndex() - 1;
        if (nextIndex < 0) {
            return;
        }
        setCurrentPage(nextIndex);
        swiperRef.current?.scrollToIndex({ index: nextIndex });
    }
    function DismissButton() {
        return (<View style={[styles.dismissIconContainer]}>
        <TouchableOpacity onPress={handleDone}>
          <Text style={[styles.dismissIcon, dismissButtonStyle]}>✕</Text>
        </TouchableOpacity>
      </View>);
    }
    function updateMaxTextHeight(height) {
        if (height > maxTextHeight) {
            setMaxTextHeight(height);
        }
    }
    const content = (<ImageBackground source={{ uri: backgroundImageUri }} resizeMode="cover" style={styles.backgroundImage}>
      <SafeAreaView style={[styles.container, style]} onLayout={onLayout}>
        {showDismissButton && <DismissButton />}
        {showHeader && HeaderComponent && (<HeaderComponent goToPreviousPage={goToPreviousPage} pages={pages} style={styles.header} Components={components} currentPage={currentPage} goToNextPage={goToNextPage}/>)}
        <View style={styles.content}>
          <SwiperFlatList scrollEnabled={enableScroll} onChangeIndex={handleIndexChange} ref={swiperRef} index={currentPage} autoplay={autoPlay}>
            {pages?.map((pageData, index) => pageData.type && pagesMerged[pageData.type] ? (<View key={index} style={{ width: containerWidth }}>
                  {pagesMerged[pageData.type]({
                style: pageStyle,
                textStyle,
                titleStyle,
                subtitleStyle,
                pageData,
                pageIndex: index,
                currentPage,
                totalPages: pages?.length,
                goToNextPage,
                goToPreviousPage,
                textAlign,
                width: containerWidth,
                props: pageData.props,
                customVariables,
                onSaveData: (data) => {
                    if (onSaveData) {
                        onSaveData(data, getPageId(pageData, index));
                    }
                },
            })}
                </View>) : (<View key={index} style={{ width: containerWidth }}>
                  <Page style={pageStyle} titleStyle={titleStyle} subtitleStyle={subtitleStyle} textStyle={textStyle} pageData={pageData} pageIndex={index} currentPage={currentPage} totalPages={pages?.length} goToNextPage={goToNextPage} goToPreviousPage={goToPreviousPage} textAlign={textAlign} width={containerWidth} maxTextHeight={maxTextHeight} setMaxTextHeight={updateMaxTextHeight} customVariables={customVariables} onSaveData={(data) => {
                if (onSaveData) {
                    onSaveData(data, getPageId(pageData, index));
                }
            }}/>
                </View>))}
          </SwiperFlatList>
        </View>
        {showFooter && (<FooterComponent paginationSelectedColor={paginationSelectedColor} paginationColor={paginationColor} goToPreviousPage={goToPreviousPage} pages={pages} style={styles.footer} Components={components} currentPage={currentPage} goToNextPage={goToNextPage}/>)}
      </SafeAreaView>
    </ImageBackground>);
    if (fullscreenModal === true || type === 'fullscreen') {
        return <Modal visible={modalVisible}>{content}</Modal>;
    }
    if (type === 'bottom-sheet') {
        return (<BottomSheet height={windowHeight * 0.8} ref={bottomSheetRef}>
        {content}
      </BottomSheet>);
    }
    return content;
};
const styles = StyleSheet.create({
    footer: {
        flex: 1,
        paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
        justifyContent: 'flex-end',
        flexDirection: 'column',
    },
    button: {
        backgroundColor: '#000',
        width: '100%',
        borderRadius: 32,
        marginTop: VERTICAL_PADDING_DEFAULT,
        marginBottom: VERTICAL_PADDING_DEFAULT,
    },
    buttonText: {
        color: '#fff',
        fontSize: 18,
        fontWeight: '500',
        textAlign: 'center',
        paddingVertical: VERTICAL_PADDING_DEFAULT,
    },
    container: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-between',
        alignItems: 'stretch',
        alignContent: 'space-between',
    },
    content: {
        flex: 1,
        flexGrow: 4,
    },
    backgroundImage: {
        flex: 1,
    },
    buttonBackgroundImage: {
        borderRadius: 32,
        marginHorizontal: 32,
    },
    dismissIcon: {
        fontSize: 22,
        width: 30,
        height: 30,
        textAlign: 'center',
        lineHeight: 30,
        backgroundColor: 'transparent',
    },
    dismissIconContainer: {
        position: 'absolute',
        flex: 1,
        top: VERTICAL_PADDING_DEFAULT * 2,
        right: HORIZONTAL_PADDING_DEFAULT,
        zIndex: 1000,
    },
    header: {
        height: 64,
        paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
        width: '100%',
    },
});

==> react-native-onboard-2.4.26.tgz: package/lib/OnboardFlow/index.js <==
import React, { useEffect, useRef, useState } from 'react';
import { Dimensions, ImageBackground, Modal, SafeAreaView, StyleSheet, Text, TouchableOpacity, View, } from 'react-native';
import { Page } from './Page';
import { SwiperFlatList } from './Swiper';
import { COLOR_PRIMARY_DEFAULT, COLOR_SECONDARY_DEFAULT, DEFAULT_PAGE_TYPES, HORIZONTAL_PADDING_DEFAULT, VERTICAL_PADDING_DEFAULT, } from './constants';
import { PrimaryButton } from './components/PrimaryButton';
import { Footer } from './Footer';
import { SecondaryButton } from './components/SecondaryButton';
import { DotPagination } from './Pagination/components/Dot';
import { BottomSheet } from './BottomSheet';
export const OnboardFlow = ({ autoPlay = false, backgroundImageUri, dismissButtonStyle, fullscreenModal, textStyle, onBack, onDone, onNext, onSaveData, pageStyle, pageTypes = DEFAULT_PAGE_TYPES, pages, paginationColor = COLOR_SECONDARY_DEFAULT, paginationSelectedColor = COLOR_PRIMARY_DEFAULT, showDismissButton = false, enableScroll = true, style, subtitleStyle, textAlign = 'center', titleStyle, type = 'fullscreen', HeaderComponent = () => null, customVariables = {}, FooterComponent = Footer, PaginationComponent = DotPagination, PrimaryButtonComponent = PrimaryButton, SecondaryButtonComponent = SecondaryButton, primaryColor = COLOR_PRIMARY_DEFAULT, secondaryColor = COLOR_SECONDARY_DEFAULT, ...props }) => {
    const pagesMerged = { ...DEFAULT_PAGE_TYPES, ...pageTypes };
    const [currentPage, setCurrentPage] = useState(0);
    const [modalVisible, setModalVisible] = useState(true);
    const swiperRef = useRef();
    const [containerWidth, setContainerWidth] = useState(Dimensions.get('window').width ?? 0);
    const windowHeight = Dimensions.get('window').height;
    const [maxTextHeight, setMaxTextHeight] = useState(0);
    const bottomSheetRef = useRef(null);
    const showHeader = pages[currentPage].showHeader == undefined || pages[currentPage].showHeader === true;
    const showFooter = pages[currentPage].showFooter == undefined || pages[currentPage].showFooter === true;
    const components = {
        PrimaryButtonComponent,
        PaginationComponent,
        SecondaryButtonComponent,
    };
    const onLayout = (event) => {
        setContainerWidth(event.nativeEvent.layout.width);
    };
    useEffect(() => {
        if (onSaveData && pages[currentPage]) {
            onSaveData({
                data: {
                    type: 'IMPRESSION',
                    page: pages[currentPage].type ?? 'default',
                },
                source: pages[currentPage],
            }, getPageId(pages[currentPage], currentPage));
        }
    }, [currentPage]);
    function getPageId(pageData, index) {
        return pageData?.id ?? index + '';
    }
    function handleIndexChange(item) {
        if (item.index != currentPage) {
            setCurrentPage(item.index);
        }
        if (item.index > item.prevIndex) {
            onNext && onNext();
            return;
        }
        if (item.index < item.prevIndex) {
            onBack && onBack();
            return;
        }
    }
    function handleDone() {
        setModalVisible(false);
        bottomSheetRef.current?.close();
        onDone && onDone();
    }
    function goToNextPage() {
        if (currentPage >= pages?.length - 1) {
            handleDone();
            return;
        }
        const nextIndex = swiperRef.current?.getCurrentIndex() + 1;
        setCurrentPage(nextIndex);
        swiperRef.current?.scrollToIndex({ index: nextIndex });
    }
    function goToPreviousPage() {
        const nextIndex = swiperRef.current?.getCurrentIndex() - 1;
        if (nextIndex < 0) {
            return;
        }
        setCurrentPage(nextIndex);
        swiperRef.current?.scrollToIndex({ index: nextIndex });
    }
    function DismissButton() {
        return (<View style={[styles.dismissIconContainer]}>
        <TouchableOpacity onPress={handleDone}>
          <Text style={[styles.dismissIcon, dismissButtonStyle]}>✕</Text>
        </TouchableOpacity>
      </View>);
    }
    function updateMaxTextHeight(height) {
        if (height > maxTextHeight) {
            setMaxTextHeight(height);
        }
    }
    const content = (<ImageBackground source={{ uri: backgroundImageUri }} resizeMode="cover" style={styles.backgroundImage}>
      <SafeAreaView style={[styles.container, style]} onLayout={onLayout}>
        {showDismissButton && <DismissButton />}
        {showHeader && HeaderComponent && (<HeaderComponent goToPreviousPage={goToPreviousPage} pages={pages} style={styles.header} Components={components} currentPage={currentPage} goToNextPage={goToNextPage}/>)}
        <View style={styles.content}>
          <SwiperFlatList scrollEnabled={enableScroll} onChangeIndex={handleIndexChange} ref={swiperRef} index={currentPage} autoplay={autoPlay}>
            {pages?.map((pageData, index) => pageData.type && pagesMerged[pageData.type] ? (<View key={index} style={{ width: containerWidth }}>
                  {pagesMerged[pageData.type]({
                style: pageStyle,
                textStyle,
                titleStyle,
                subtitleStyle,
                pageData,
                pageIndex: index,
                currentPage,
                totalPages: pages?.length,
                goToNextPage,
                goToPreviousPage,
                textAlign,
                width: containerWidth,
                props: pageData.props,
                customVariables,
                primaryColor,
                secondaryColor,
                onSaveData: (data) => {
                    if (onSaveData) {
                        onSaveData(data, getPageId(pageData, index));
                    }
                },
            })}
                </View>) : (<View key={index} style={{ width: containerWidth }}>
                  <Page style={pageStyle} titleStyle={titleStyle} subtitleStyle={subtitleStyle} textStyle={textStyle} pageData={pageData} pageIndex={index} currentPage={currentPage} totalPages={pages?.length} goToNextPage={goToNextPage} goToPreviousPage={goToPreviousPage} textAlign={textAlign} width={containerWidth} maxTextHeight={maxTextHeight} setMaxTextHeight={updateMaxTextHeight} customVariables={customVariables} primaryColor={primaryColor} secondaryColor={secondaryColor} onSaveData={(data) => {
                if (onSaveData) {
                    onSaveData(data, getPageId(pageData, index));
                }
            }}/>
                </View>))}
          </SwiperFlatList>
        </View>
        {showFooter && (<FooterComponent paginationSelectedColor={paginationSelectedColor} paginationColor={paginationColor} goToPreviousPage={goToPreviousPage} pages={pages} style={styles.footer} Components={components} currentPage={currentPage} goToNextPage={goToNextPage}/>)}
      </SafeAreaView>
    </ImageBackground>);
    if (fullscreenModal === true || type === 'fullscreen') {
        return <Modal visible={modalVisible}>{content}</Modal>;
    }
    if (type === 'bottom-sheet') {
        return (<BottomSheet height={windowHeight * 0.8} ref={bottomSheetRef}>
        {content}
      </BottomSheet>);
    }
    return content;
};
const styles = StyleSheet.create({
    footer: {
        flex: 1,
        paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
        justifyContent: 'flex-end',
        flexDirection: 'column',
    },
    button: {
        backgroundColor: '#000',
        width: '100%',
        borderRadius: 32,
        marginTop: VERTICAL_PADDING_DEFAULT,
        marginBottom: VERTICAL_PADDING_DEFAULT,
    },
    buttonText: {
        color: '#fff',
        fontSize: 18,
        fontWeight: '500',
        textAlign: 'center',
        paddingVertical: VERTICAL_PADDING_DEFAULT,
    },
    container: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-between',
        alignItems: 'stretch',
        alignContent: 'space-between',
    },
    content: {
        flex: 1,
        flexGrow: 4,
    },
    backgroundImage: {
        flex: 1,
    },
    buttonBackgroundImage: {
        borderRadius: 32,
        marginHorizontal: 32,
    },
    dismissIcon: {
        fontSize: 22,
        width: 30,
        height: 30,
        textAlign: 'center',
        lineHeight: 30,
        backgroundColor: 'transparent',
    },
    dismissIconContainer: {
        position: 'absolute',
        flex: 1,
        top: VERTICAL_PADDING_DEFAULT * 2,
        right: HORIZONTAL_PADDING_DEFAULT,
        zIndex: 1000,
    },
    header: {
        height: 64,
        paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
        width: '100%',
    },
});
